# Score Timing Data Schema

```txt
http://example.com/schemas/score-timing-data
```

Score timing data.

| Abstract            | Extensible | Status         | Identifiable | Custom Properties | Additional Properties | Access Restrictions | Defined In                                                                                   |
| :------------------ | :--------- | :------------- | :----------- | :---------------- | :-------------------- | :------------------ | :------------------------------------------------------------------------------------------- |
| Can be instantiated | Yes        | Unknown status | No           | Forbidden         | Allowed               | none                | [score-timing-data.schema.json](../out/score-timing-data.schema.json "open original schema") |

## Score Timing Data Type

`object` ([Score Timing Data](score-timing-data.md))

# Score Timing Data Properties

| Property                    | Type     | Required | Nullable       | Defined by                                                                                                                               |
| :-------------------------- | :------- | :------- | :------------- | :--------------------------------------------------------------------------------------------------------------------------------------- |
| [baseTempo](#basetempo)     | `object` | Required | cannot be null | [Score Timing Data](score-timing-data-definitions-base-tempo.md "http://example.com/schemas/score-timing-data#/properties/baseTempo")    |
| [endPosition](#endposition) | Merged   | Required | cannot be null | [Score Timing Data](score-timing-data-properties-end-position.md "http://example.com/schemas/score-timing-data#/properties/endPosition") |
| [meterParts](#meterparts)   | `array`  | Required | cannot be null | [Score Timing Data](score-timing-data-properties-meter-parts.md "http://example.com/schemas/score-timing-data#/properties/meterParts")   |
| [tempoParts](#tempoparts)   | `array`  | Required | cannot be null | [Score Timing Data](score-timing-data-properties-tempo-parts.md "http://example.com/schemas/score-timing-data#/properties/tempoParts")   |
| [players](#players)         | `object` | Required | cannot be null | [Score Timing Data](score-timing-data-properties-players.md "http://example.com/schemas/score-timing-data#/properties/players")          |

## baseTempo

The global base tempo. All other tempi are expressed as fractions of this value.

`baseTempo`

*   is required

*   Type: `object` ([Base Tempo](score-timing-data-definitions-base-tempo.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-base-tempo.md "http://example.com/schemas/score-timing-data#/properties/baseTempo")

### baseTempo Type

`object` ([Base Tempo](score-timing-data-definitions-base-tempo.md))

## endPosition

The end position of the score. This is the duration from the start of the score and is expressed as a fraction or integer multiplier of a whole note at the base tempo.

`endPosition`

*   is required

*   Type: merged type ([End Position](score-timing-data-properties-end-position.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-properties-end-position.md "http://example.com/schemas/score-timing-data#/properties/endPosition")

### endPosition Type

merged type ([End Position](score-timing-data-properties-end-position.md))

one (and only one) of

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-0.md "check type definition")

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-1.md "check type definition")

## meterParts

An array of parts containing independent meters.

`meterParts`

*   is required

*   Type: `object[][]` ([Meter Object](score-timing-data-definitions-meter-object.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-properties-meter-parts.md "http://example.com/schemas/score-timing-data#/properties/meterParts")

### meterParts Type

`object[][]` ([Meter Object](score-timing-data-definitions-meter-object.md))

### meterParts Constraints

**minimum number of items**: the minimum number of items for this array is: `1`

## tempoParts

An array of parts containing independent tempi.

`tempoParts`

*   is required

*   Type: `object[][]` ([Tempo Object](score-timing-data-definitions-tempo-object.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-properties-tempo-parts.md "http://example.com/schemas/score-timing-data#/properties/tempoParts")

### tempoParts Type

`object[][]` ([Tempo Object](score-timing-data-definitions-tempo-object.md))

### tempoParts Constraints

**minimum number of items**: the minimum number of items for this array is: `1`

## players

An object mapping players to meter and tempo parts.

`players`

*   is required

*   Type: `object` ([Players](score-timing-data-properties-players.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-properties-players.md "http://example.com/schemas/score-timing-data#/properties/players")

### players Type

`object` ([Players](score-timing-data-properties-players.md))

### players Constraints

**minimum number of properties**: the minimum number of properties for this object is: `1`

# Score Timing Data Definitions

## Definitions group baseTempo

Reference this group by using

```json
{"$ref":"http://example.com/schemas/score-timing-data#/definitions/baseTempo"}
```

| Property              | Type     | Required | Nullable       | Defined by                                                                                                                                                           |
| :-------------------- | :------- | :------- | :------------- | :------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| [beatUnit](#beatunit) | Merged   | Required | cannot be null | [Score Timing Data](score-timing-data-definitions-integerorfraction.md "http://example.com/schemas/score-timing-data#/definitions/baseTempo/properties/beatUnit")    |
| [bpm](#bpm)           | `number` | Required | cannot be null | [Score Timing Data](score-timing-data-definitions-base-tempo-properties-bpm.md "http://example.com/schemas/score-timing-data#/definitions/baseTempo/properties/bpm") |

### beatUnit

The beat unit of the base tempo. Expressed as a fraction or integer multiplier of a whole note.

`beatUnit`

*   is required

*   Type: merged type ([Beat Unit](score-timing-data-definitions-integerorfraction.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-integerorfraction.md "http://example.com/schemas/score-timing-data#/definitions/baseTempo/properties/beatUnit")

#### beatUnit Type

merged type ([Beat Unit](score-timing-data-definitions-integerorfraction.md))

one (and only one) of

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-0.md "check type definition")

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-1.md "check type definition")

#### beatUnit Default Value

The default value is:

```json
"1/4"
```

### bpm

The number of beats per minute at the base tempo.

`bpm`

*   is required

*   Type: `number` ([BPM](score-timing-data-definitions-base-tempo-properties-bpm.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-base-tempo-properties-bpm.md "http://example.com/schemas/score-timing-data#/definitions/baseTempo/properties/bpm")

#### bpm Type

`number` ([BPM](score-timing-data-definitions-base-tempo-properties-bpm.md))

#### bpm Constraints

**minimum (exclusive)**: the value of this number must be greater than: `0`

#### bpm Default Value

The default value is:

```json
120
```

## Definitions group meter

Reference this group by using

```json
{"$ref":"http://example.com/schemas/score-timing-data#/definitions/meter"}
```

| Property                        | Type     | Required | Nullable       | Defined by                                                                                                                                                                          |
| :------------------------------ | :------- | :------- | :------------- | :---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| [meter](#meter)                 | Merged   | Required | cannot be null | [Score Timing Data](score-timing-data-definitions-meter-object-properties-meter.md "http://example.com/schemas/score-timing-data#/definitions/meter/properties/meter")              |
| [startPosition](#startposition) | Merged   | Required | cannot be null | [Score Timing Data](score-timing-data-definitions-integerorfraction.md "http://example.com/schemas/score-timing-data#/definitions/meter/properties/startPosition")                  |
| [endPosition](#endposition-1)   | Merged   | Required | cannot be null | [Score Timing Data](score-timing-data-definitions-integerorfraction.md "http://example.com/schemas/score-timing-data#/definitions/meter/properties/endPosition")                    |
| [beatPattern](#beatpattern)     | `array`  | Optional | cannot be null | [Score Timing Data](score-timing-data-definitions-meter-object-properties-beat-pattern.md "http://example.com/schemas/score-timing-data#/definitions/meter/properties/beatPattern") |
| [countIn](#countin)             | `object` | Optional | cannot be null | [Score Timing Data](score-timing-data-definitions-meter-object-properties-count-in.md "http://example.com/schemas/score-timing-data#/definitions/meter/properties/countIn")         |

### meter

The meter (time signature). Expressed as a fraction, as 'open' or as 'pickup'.

`meter`

*   is required

*   Type: merged type ([Meter](score-timing-data-definitions-meter-object-properties-meter.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-meter-object-properties-meter.md "http://example.com/schemas/score-timing-data#/definitions/meter/properties/meter")

#### meter Type

merged type ([Meter](score-timing-data-definitions-meter-object-properties-meter.md))

one (and only one) of

*   [Untitled string in Score Timing Data](score-timing-data-definitions-meter-object-properties-meter-oneof-0.md "check type definition")

*   [Untitled string in Score Timing Data](score-timing-data-definitions-meter-object-properties-meter-oneof-1.md "check type definition")

#### meter Default Value

The default value is:

```json
"4/4"
```

### startPosition

The start position of the meter. This is the duration from the start of the score and is expressed as a fraction or integer multiplier of a whole note at the base tempo.

`startPosition`

*   is required

*   Type: merged type ([Start Position](score-timing-data-definitions-integerorfraction.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-integerorfraction.md "http://example.com/schemas/score-timing-data#/definitions/meter/properties/startPosition")

#### startPosition Type

merged type ([Start Position](score-timing-data-definitions-integerorfraction.md))

one (and only one) of

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-0.md "check type definition")

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-1.md "check type definition")

### endPosition

The end position of the meter. This is the duration from the start of the score and is expressed as a fraction or integer multiplier of a whole note at the base tempo.

`endPosition`

*   is required

*   Type: merged type ([End Position](score-timing-data-definitions-integerorfraction.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-integerorfraction.md "http://example.com/schemas/score-timing-data#/definitions/meter/properties/endPosition")

#### endPosition Type

merged type ([End Position](score-timing-data-definitions-integerorfraction.md))

one (and only one) of

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-0.md "check type definition")

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-1.md "check type definition")

### beatPattern

An optional array containing the beat durations. Each entry is expressed as a fraction of a whole note at the current tempo. If the total pattern duration is shorter than the section duration, the pattern is repeated until they are equal. If omitted, the beat unit of the meter is used.

`beatPattern`

*   is optional

*   Type: an array of merged types ([Beat Duration](score-timing-data-definitions-integerorfraction.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-meter-object-properties-beat-pattern.md "http://example.com/schemas/score-timing-data#/definitions/meter/properties/beatPattern")

#### beatPattern Type

an array of merged types ([Beat Duration](score-timing-data-definitions-integerorfraction.md))

### countIn

An optional count-in.

`countIn`

*   is optional

*   Type: `object` ([Count-in](score-timing-data-definitions-meter-object-properties-count-in.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-meter-object-properties-count-in.md "http://example.com/schemas/score-timing-data#/definitions/meter/properties/countIn")

#### countIn Type

`object` ([Count-in](score-timing-data-definitions-meter-object-properties-count-in.md))

## Definitions group tempo

Reference this group by using

```json
{"$ref":"http://example.com/schemas/score-timing-data#/definitions/tempo"}
```

| Property                          | Type   | Required | Nullable       | Defined by                                                                                                                                                         |
| :-------------------------------- | :----- | :------- | :------------- | :----------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| [tempo](#tempo)                   | Merged | Required | cannot be null | [Score Timing Data](score-timing-data-definitions-integerorfraction.md "http://example.com/schemas/score-timing-data#/definitions/tempo/properties/tempo")         |
| [startPosition](#startposition-1) | Merged | Required | cannot be null | [Score Timing Data](score-timing-data-definitions-integerorfraction.md "http://example.com/schemas/score-timing-data#/definitions/tempo/properties/startPosition") |

### tempo

The tempo. Expressed as a fraction or integer multiplier of the base tempo.

`tempo`

*   is required

*   Type: merged type ([Tempo](score-timing-data-definitions-integerorfraction.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-integerorfraction.md "http://example.com/schemas/score-timing-data#/definitions/tempo/properties/tempo")

#### tempo Type

merged type ([Tempo](score-timing-data-definitions-integerorfraction.md))

one (and only one) of

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-0.md "check type definition")

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-1.md "check type definition")

#### tempo Default Value

The default value is:

```json
"1/1"
```

### startPosition

The start position of the tempo. This is the duration from the start of the score and is expressed as a fraction or integer multiplier of a whole note at the base tempo.

`startPosition`

*   is required

*   Type: merged type ([Start Position](score-timing-data-definitions-integerorfraction.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-integerorfraction.md "http://example.com/schemas/score-timing-data#/definitions/tempo/properties/startPosition")

#### startPosition Type

merged type ([Start Position](score-timing-data-definitions-integerorfraction.md))

one (and only one) of

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-0.md "check type definition")

*   [Untitled string in Score Timing Data](score-timing-data-definitions-integerorfraction-oneof-1.md "check type definition")

## Definitions group player

Reference this group by using

```json
{"$ref":"http://example.com/schemas/score-timing-data#/definitions/player"}
```

| Property                          | Type      | Required | Nullable       | Defined by                                                                                                                                                                            |
| :-------------------------------- | :-------- | :------- | :------------- | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| [meterPartIndex](#meterpartindex) | `integer` | Required | cannot be null | [Score Timing Data](score-timing-data-definitions-player-properties-meter-part-index.md "http://example.com/schemas/score-timing-data#/definitions/player/properties/meterPartIndex") |
| [tempoPartIndex](#tempopartindex) | `integer` | Required | cannot be null | [Score Timing Data](score-timing-data-definitions-player-properties-tempo-part-index.md "http://example.com/schemas/score-timing-data#/definitions/player/properties/tempoPartIndex") |

### meterPartIndex

An index linking to an entry in the meter part array.

`meterPartIndex`

*   is required

*   Type: `integer` ([Meter Part Index](score-timing-data-definitions-player-properties-meter-part-index.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-player-properties-meter-part-index.md "http://example.com/schemas/score-timing-data#/definitions/player/properties/meterPartIndex")

#### meterPartIndex Type

`integer` ([Meter Part Index](score-timing-data-definitions-player-properties-meter-part-index.md))

#### meterPartIndex Constraints

**minimum**: the value of this number must greater than or equal to: `0`

### tempoPartIndex

An index linking to an entry in the tempo part array.

`tempoPartIndex`

*   is required

*   Type: `integer` ([Tempo Part Index](score-timing-data-definitions-player-properties-tempo-part-index.md))

*   cannot be null

*   defined in: [Score Timing Data](score-timing-data-definitions-player-properties-tempo-part-index.md "http://example.com/schemas/score-timing-data#/definitions/player/properties/tempoPartIndex")

#### tempoPartIndex Type

`integer` ([Tempo Part Index](score-timing-data-definitions-player-properties-tempo-part-index.md))

#### tempoPartIndex Constraints

**minimum**: the value of this number must greater than or equal to: `0`

## Definitions group fraction

Reference this group by using

```json
{"$ref":"http://example.com/schemas/score-timing-data#/definitions/fraction"}
```

| Property | Type | Required | Nullable | Defined by |
| :------- | :--- | :------- | :------- | :--------- |

## Definitions group integer

Reference this group by using

```json
{"$ref":"http://example.com/schemas/score-timing-data#/definitions/integer"}
```

| Property | Type | Required | Nullable | Defined by |
| :------- | :--- | :------- | :------- | :--------- |

## Definitions group integerOrFraction

Reference this group by using

```json
{"$ref":"http://example.com/schemas/score-timing-data#/definitions/integerOrFraction"}
```

| Property | Type | Required | Nullable | Defined by |
| :------- | :--- | :------- | :------- | :--------- |
